Module callback

Module callback 

Types and functions used for handling events and adding event listeners to dom nodes.

Structs

Callback
A callback that can be used for event listeners in the function [add_event_listener], it gets passed down to the exported __afia__$handle_event function.