Context

Trait Context 

pub trait Context: Sealed {
    // Required method
    fn to_isize(&self, _: CratePrivate) -> isize;
}
Some afia-component functions have a context parameter.

This context gets passed to Afia, and then Afia later passes the context back to the site component.

Types that implement this Context trait can be used as context.

Required Methods

fn to_isize(&self, _: CratePrivate) -> isize

Get an isize representation of the Context .

Implementations on Foreign Types

Source

impl Context for isize

Source

fn to_isize(&self, _: CratePrivate) -> isize

Source

impl<T> Context for *const T

Source

fn to_isize(&self, _: CratePrivate) -> isize

Source

impl<T> Context for *mut T

Source

fn to_isize(&self, _: CratePrivate) -> isize

Implementors