Module data_element_value
afia_
component
0.0.4
Module data_
element_
value
Module Items
Enums
In crate afia_
component
afia_component
Module
data_
element_
value
Types related to getting and setting an input element’s value.
Enums

Input
Element
GetValue
Error
An error when attempting to retrieve an input element’s value.