pub enum InputElementGetValueError {
ElementIsNotHtmlInputElement,
OutBufferBelowMinimumSize,
OutBufferSmallerThanValue {
value_len: usize,
},
Unrecognized {
error_code: i32,
},
}Expand description
An error when attempting to retrieve an input element’s value.
Variants
ElementIsNotHtmlInputElement
The element was not an <input> element.
OutBufferBelowMinimumSize
The out buffer was smaller than the minimum allowed size.
OutBufferSmallerThanValue
The out buffer was smaller than the length of the input element’s value.
Unrecognized