Module input

Module input 

Types related to component inputs.

NOTE: There is an open issue that changes how component inputs work. Remove __afia__$allocate https://github.com/afia/afia/issues/2519 The current plan is that WebAssembly imports such as fn _afia_get_color_inputs() will be used to retrieve component inputs. So, it’s possible that ComponentInputs ends up getting deleted and then the behavior gets moved into ComponentImports. I have not thought about this. For now I am just implementing abstractions on top of the current system (where we have an inputs_ptr: *const u8, while still trying to ensure that the pieces of the design will be easy to move around to other places if needed. See the Components chapter in the internal book for more information about component inputs.

Modules

mock
Types used to mock a component’s inputs.

Structs

ComponentInput
Describes one of a component’s inputs.
ComponentInputs
Used to retrieve the component’s inputs.
TextInputId
Used to retrieve one of the component’s text inputs.

Enums

ValueType
Describes a component input’s type, such as Text or Color.