ComponentInputs

Struct ComponentInputs 

pub struct ComponentInputs {
    pub ctx: *mut c_void,
    pub free_ctx: fn(ctx: *mut c_void),
    pub text: fn(ctx: *mut c_void, input_id: TextInputId) -> String,
}
Used to retrieve the component’s inputs.

Fields

ctx: *mut c_void

An arbitrary context object used when determining how to retrieve the component input.

free_ctx: fn(ctx: *mut c_void)

Free the context object.

text: fn(ctx: *mut c_void, input_id: TextInputId) -> String

Get one of the component’s text inputs.

Implementations

Source

impl ComponentInputs

pub fn new(inputs_ptr: *const u8) -> Self

Create a ComponentInputs that can read inputs from the inputs pointer that Afia provides.

pub fn get_text(&self, text_id: TextInputId) -> String

Get the text input’s value.