pub enum LocalStorageGetItemError {
KeyTooLong,
KeyNotUtf8,
OutBufferBelowMinimumSize,
OutBufferSmallerThanValue {
value_len: usize,
},
Unrecognized {
error_code: i32,
},
}Expand description
An error when attempting to retrieve an value from local storage.
Variants
KeyTooLong
The key was too long.
KeyNotUtf8
The key’s bytes were not valid UTF-8.
OutBufferBelowMinimumSize
The out buffer was smaller than the length of the input element’s value.
OutBufferSmallerThanValue
The out buffer was smaller than the length of the local storage item’s value.
Unrecognized