pub enum DomNodeGetPropertyBoolError {
KeyTooLong,
KeyNotUtf8,
ValueNotBool,
Other {
error_code: i32,
},
}Expand description
An error when attempting to retrieve a boolean property from a DOM node.
Variants
KeyTooLong
The key was too long.
KeyNotUtf8
The key’s bytes were not valid UTF-8.
ValueNotBool
The property exists, but the value is not a boolean.
Other