pub enum DomNodeGetPropertyStringError {
KeyTooLong,
KeyNotUtf8,
ValueNotString,
OutBufferBelowMinimumSize,
OutBufferSmallerThanValue {
value_len: usize,
},
Other {
error_code: i32,
},
}Expand description
An error when attempting to retrieve a property from a DOM node.
Variants
KeyTooLong
The key was too long.
KeyNotUtf8
The key’s bytes were not valid UTF-8.
ValueNotString
The property exists, but the value is not a string.
OutBufferBelowMinimumSize
The out buffer was smaller than the length of the input element’s value.
OutBufferSmallerThanValue
The out buffer was smaller than the length of the local storage item’s value.
Other