ComponentImports

Struct ComponentImports 

pub struct ComponentImports { /* private fields */ }
A handle that can be used to call component imports such as ComponentImports::create_element and ComponentImports::create_text.

ComponentImports and Clone

Cloning a ComponentImports is cheap and does not allocate.

Implementations

Source

impl ComponentImports

pub fn create_element(&self, tag: &str) -> Option<DomElement>

Create a new DomElement.

Source

impl ComponentImports

pub fn create_text(&self, text: &str) -> Option<DomText>

Create a new text node in the DOM.

Source

impl ComponentImports

pub fn local_storage_get_item<'out>( &self, key: &str, out_buffer: &'out mut [u8], ) -> Result<Option<&'out str>, LocalStorageGetItemError>

Get an item from local storage.

pub fn local_storage_set_item(&self, key: &str, val: &str)

Set an item in local storage.

Source

impl ComponentImports

pub fn initialize_stripe<C: Context>(&self, context: C)

Initialize the Stripe JS SDK.

pub fn create_stripe_elements( &self, handle: &StripeJsSdkInstanceHandle, amount_cents: u32, ) -> StripeElementsHandle

Create a Stripe Elements object.

pub fn submit_stripe_elements<C: Context>( &self, handle: &StripeElementsHandle, context: C, )

Submit a Stripe Elements object.

Source

impl ComponentImports

pub fn output_may_have_changed(&self, output_id: i32)

Indicate that one of a component’s outputs may have changed.

Source

impl ComponentImports

pub const fn new_dynamically_linked() -> Self

Create a new ComponentImports that makes calls to functions that are provided by the Afia host.

Use [EmulatedImports::component_imports] to create ComponentImports during tests.