pub trait Context: Sealed {
// Required method
fn to_isize(&self, _: CratePrivate) -> isize;
}Expand description
Some afia-component functions have a context parameter.
This context gets passed to Afia, and then Afia later passes the context back to the site
component.
Types that implement this Context trait can be used as context.